@@ -18,15 +18,26 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 my $log;
 my $bcmd;
 
 sub new {
     my ($class, %args) = @_;
-    my $self = bless {}, $class;
-    %{ $self->{args} } = %args;
+    my $self = bless { }, $class;
+
+    # see if we have config file data
+
+    if ($self->config_file) {
+        $self->_config;
+    }
+
+    # override the config file and populate the rest of the args
+
+    for (keys %args){
+        $self->{args}{$_} = $args{$_};
+    }
 
     $log = $self->_create_log($args{debug});
     $log->_6("in new(), constructing " . __PACKAGE__ . " object");
@@ -110,7 +121,14 @@ sub instance_install {
 
     # timeout an install after...
 
-    $timeout = $timeout || 300;
+    if (! $timeout){
+        if ($self->{args}{timeout}){
+            $timeout = $self->{args}{timeout};
+        }
+        else {
+            $timeout = 300;
+        }
+    }
 
     my $log = $log->child('instance_install');
 
@@ -148,6 +166,17 @@ sub instance_install {
             }
             push @new_installs, $version;
         }
+    }
+     elsif ($install == -1) {
+        $log->_5("installing all available perls");
+
+        for my $perl (@perls_available){
+            if (grep { $_ eq $perl } @perls_installed) {
+                $log->_6( "$perl already installed... skipping" );
+                next;
+            }
+            push @new_installs, $perl;
+        }
     }
     elsif ($install) {
         $log->_5("looking to install $install perl instance(s)");
@@ -169,17 +198,6 @@ sub instance_install {
             $install--;
         }
     }
-    elsif ($install == -1) {
-        $log->_5("installing all available perls");
-
-        for my $perl (@perls_available){
-            if (grep { $_ eq $perl } @perls_installed) {
-                $log->_6( "$perl already installed... skipping" );
-                next;
-            }
-            push @new_installs, $perl;
-        }
-    }
 
     if (@new_installs){
         $log->_4("preparing to install..." . join ', ', @new_installs);
@@ -271,7 +289,6 @@ sub revdep {
     $args{plugin} = 'Test::BrewBuild::Plugin::TestAgainst';
 
     my @revdeps = $self->revdeps;
-
     my @ret;
 
     my $rlist = "\nreverse dependencies: " . join ', ', @revdeps;
@@ -376,8 +393,6 @@ sub revdeps {
     my $log = $log->child('revdeps');
     $log->_6('running --revdep');
 
-    load 'CPAN::ReverseDependencies';
-
     my @modules;
 
     find({
@@ -402,15 +417,7 @@ sub revdeps {
 
     $log->_7("working module translated to $mod");
 
-    my $rvdep = CPAN::ReverseDependencies->new;
-    my @revdeps = $rvdep->get_reverse_dependencies($mod);
-
-    @revdeps = grep {$_ ne 'Test-BrewBuild'} @revdeps;
-
-    for (@revdeps){
-        s/-/::/g;
-    }
-
+    my @revdeps = $self->_get_revdeps($mod);
     return @revdeps;
 }
 sub legacy {
@@ -463,6 +470,20 @@ Special options:
 EOF
 return 1;
 }
+sub _config {
+    # slurp in config file elements
+
+    my $self = shift;
+
+     my $conf_file = $self->config_file;
+
+    if (-f $conf_file){
+        my $conf = Config::Tiny->read($conf_file)->{brewbuild};
+        for (keys %$conf){
+            $self->{args}{$_} = $conf->{$_};
+        }
+    }
+}
 sub _attach_build_log {
     # attach the cpanm logs to the PASS/FAIL logs
 
@@ -684,6 +705,29 @@ sub _dzil_unshim {
     chdir '..';
     $log->_7("changed to '..' dir");
 }
+sub _get_revdeps {
+    my ($self, $module) = @_;
+
+    load 'MetaCPAN::Client';
+
+    my $mcpan = MetaCPAN::Client->new;
+
+    my $rs = $mcpan->reverse_dependencies($module);
+
+    my @revdeps;
+
+    while (my $release = $rs->next){
+        push @revdeps, $release->distribution;
+    }
+
+    @revdeps = grep {$_ ne 'Test-BrewBuild'} @revdeps;
+
+    for (@revdeps) {
+        s/-/::/g;
+    }
+
+    return @revdeps;
+}
 sub _process_stderr {
     # compile data written to STDERR
 
@@ -882,12 +926,18 @@ All unit tests are run against all installed instances.
 
 =head1 METHODS
 
+
+
 =head2 new(%args)
 
 Returns a new C<Test::BrewBuild> object. See the documentation for the
 L<brewbuild|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/brewbuild>
 script to understand what the arguments are and do.
 
+Many of the options can be saved in a configuration file if you want to set them
+permanently, or override defaults. Options passed into the various methods will
+override those in the configuration file. See L<Test::BrewBuild::brewbuild.conf>.
+
 =head2 brew_info
 
 Returns in string form the full output of C<*brew available>.
