@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 my $log;
 
@@ -40,7 +40,7 @@ sub brew {
         $brew = 'perlbrew';
     }
 
-    $log->child('brew')->_6("*brew cmd is: $brew");
+    $log->child('brew')->_6("*brew cmd is: $brew") if $brew;
     $self->{brew} = $brew;
 
     return $brew;
@@ -97,7 +97,10 @@ sub available {
     if (! $legacy){
         @avail = grep { /^(?:perl-)?5\.(\d+)/; $1 > 8 } @avail;
     }
-    return @avail;
+
+    my %seen;
+    $seen{$_}++ for @avail;
+    return keys %seen;
 }
 sub install {
     my $self = shift;
